Deleters
========

.. automodule:: stonesoup.deleter
    :no-members:

.. automodule:: stonesoup.deleter.base
    :show-inheritance:

Error Based
-----------
.. automodule:: stonesoup.deleter.error
    :show-inheritance:
    :inherited-members:

Time Based
-----------
.. automodule:: stonesoup.deleter.time
    :show-inheritance:
    :inherited-members:
